@@ -14,6 +14,6 @@ directory = "$(pwd)/rust-vendor"
 EOL
 
 # Run the actual test
-CARGO_HOME=$CARGO_TMP_DIR cargo test --offline --manifest-path Cargo.toml --features=pam-login,apparmor,sudoedit --all-targets -- --skip test_build_run_context --skip test_traverse_secure_open_positive
+CARGO_HOME=$CARGO_TMP_DIR cargo test --offline --manifest-path Cargo.toml --features=pam-login,apparmor,sudoedit --all-targets -- --skip test_traverse_secure_open_positive
 
 rm -rf $CARGO_TMP_DIR
